pub async fn get_cluster_nodes(
infra: &InfraContext<'_>,
token: &str,
params: &GetClusterParams,
) -> Result<Vec<NodeDetails>, Error>Expand description
Fetch node details for all nodes in the specified HSM groups.
pub async fn get_cluster_nodes(
infra: &InfraContext<'_>,
token: &str,
params: &GetClusterParams,
) -> Result<Vec<NodeDetails>, Error>Fetch node details for all nodes in the specified HSM groups.